==> haskell-parsers-0.12.8-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsers
version: 0.12.8
id: parsers-0.12.8-1Lcj4PYeOJeoQk9dQ6Vxu
key: parsers-0.12.8-1Lcj4PYeOJeoQk9dQ6Vxu
license: BSD3
copyright: Copyright (C) 2010-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/parsers/
synopsis: Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.
    .
    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".
category: Text, Parsing
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.Expression
    Text.Parser.LookAhead Text.Parser.Permutation Text.Parser.Token
    Text.Parser.Token.Highlight Text.Parser.Token.Style
abi: 5f7ee0aea22e3b08822cacf02ea44e85
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/parsers-0.12.8
library-dirs: /usr/lib/ghc-8.2.2/site-local/parsers-0.12.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/parsers-0.12.8
hs-libraries: HSparsers-0.12.8-1Lcj4PYeOJeoQk9dQ6Vxu
depends:
    base-4.10.1.0 base-orphans-0.6-KoJqNefbvUAEuaR7CDOiu4
    charset-0.3.7.1-306mtOKyuvyDYrsMHTuRjc containers-0.5.10.2
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    parsec-3.1.13.0-E3xu0p0JtSPICcgXxkVqap
    attoparsec-0.13.2.2-6Afec3PTeJ8I3cxSKL61mm
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj transformers-0.5.2.0
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    scientific-0.3.5.2-IWSZVQGiPwx2zNrAPvmBEO
    unordered-containers-0.2.9.0-14GJxyni7Ou4ztgK034uJm
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-orphans-0.6-KoJqNefbvUAEuaR7CDOiu4=fb09ffe63c021a5df200f5dd3f288699
             charset-0.3.7.1-306mtOKyuvyDYrsMHTuRjc=1dbd7126f0bc28001ac751e2840f1af2
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             parsec-3.1.13.0-E3xu0p0JtSPICcgXxkVqap=e5bced146b6517b43ed5d06001479bde
             attoparsec-0.13.2.2-6Afec3PTeJ8I3cxSKL61mm=dbf2a2c6556965dad88a2349e873212b
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             scientific-0.3.5.2-IWSZVQGiPwx2zNrAPvmBEO=6e538d6297179a35ae8f400426125b37
             unordered-containers-0.2.9.0-14GJxyni7Ou4ztgK034uJm=a19fc431946ec4b21dbc4dc9d0f6448c
haddock-interfaces: /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html: /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parsers-0.12.8-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsers
version: 0.12.8
id: parsers-0.12.8-CdyIirYfJfh1pHubW2ftNW
key: parsers-0.12.8-CdyIirYfJfh1pHubW2ftNW
license: BSD3
copyright: Copyright (C) 2010-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/parsers/
synopsis: Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.
    .
    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".
category: Text, Parsing
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.Expression
    Text.Parser.LookAhead Text.Parser.Permutation Text.Parser.Token
    Text.Parser.Token.Highlight Text.Parser.Token.Style
abi: d84931779d7bfa5f546b092e700ea0f3
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/parsers-0.12.8
library-dirs: /usr/lib/ghc-8.2.2/site-local/parsers-0.12.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/parsers-0.12.8
hs-libraries: HSparsers-0.12.8-CdyIirYfJfh1pHubW2ftNW
depends:
    base-4.10.1.0 base-orphans-0.6-KoJqNefbvUAEuaR7CDOiu4
    charset-0.3.7.1-LxunnvRYoJTFQNeJWnyrEN containers-0.5.10.2
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp
    attoparsec-0.13.2.2-9rrXZSTFIKACL1r4WeB8Up
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz transformers-0.5.2.0
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    scientific-0.3.5.2-8Zc2VroUo3iF9E3c5Pz1Qw
    unordered-containers-0.2.9.0-G7T2IXGR99p4cQdXRUBkNA
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-orphans-0.6-KoJqNefbvUAEuaR7CDOiu4=fb09ffe63c021a5df200f5dd3f288699
             charset-0.3.7.1-LxunnvRYoJTFQNeJWnyrEN=e72665541e9a63e85643f4e64084a771
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp=b942a04aec0a266706b2e8e67bd137e3
             attoparsec-0.13.2.2-9rrXZSTFIKACL1r4WeB8Up=0f65d953ef6806e52476b2e8588d0370
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             scientific-0.3.5.2-8Zc2VroUo3iF9E3c5Pz1Qw=11abcce15758b0e3fff5fe5ecd138e8b
             unordered-containers-0.2.9.0-G7T2IXGR99p4cQdXRUBkNA=bcd116646f2dca4381cb4b7cc7ba7fb1
haddock-interfaces: /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html: /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
